%global gem_name charlock_holmes

Name: rubygem-%{gem_name}
Version: 0.7.3
Release: 28%{?dist}
Summary: Character encoding detection, brought to you by ICU
License: MIT
URL: https://github.com/brianmario/charlock_holmes
Source0: https://rubygems.org/gems/%{gem_name}-%{version}.gem
# Fix ICU 61+ compatibility.
# https://github.com/brianmario/charlock_holmes/pull/127
Patch0: rubygem-charlock_holmes-0.7.6-Qualify-icu-types-explicitly.patch
BuildRequires: gcc-c++
BuildRequires: ruby(release)
BuildRequires: rubygems-devel
BuildRequires: ruby-devel
BuildRequires: libicu-devel
BuildRequires: zlib-devel
BuildRequires: rubygem(minitest)

# The Python code in the tests subdirectory references /usr/bin/env.
# Filter this from RPM's autorequires.
%global __requires_exclude ^/usr/bin/env$

%description
Character encoding detecting library for Ruby using ICU

%package doc
Summary: Documentation for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
Documentation for %{name}

%prep
gem unpack %{SOURCE0}

%setup -q -D -T -n  %{gem_name}-%{version}

gem spec %{SOURCE0} -l --ruby > %{gem_name}.gemspec

%patch0 -p1

# Remove unecessary bundler dependency
sed -i '/bundler/d' test/helper.rb

# Remove ambiguous shebang
sed -r -i '/#!\/usr\/bin\/env/d' test/fixtures/laholator.py

%build
# Create the gem as gem install only works on a gem file
gem build %{gem_name}.gemspec

# %%gem_install compiles any C extensions and installs the gem into ./%%gem_dir
# by default, so that we can move it into the buildroot in %%install
%gem_install

%install
mkdir -p %{buildroot}%{gem_dir}
cp -pa .%{gem_dir}/* \
        %{buildroot}%{gem_dir}/

mkdir -p %{buildroot}%{gem_extdir_mri}
cp -pa .%{gem_extdir_mri}/* %{buildroot}%{gem_extdir_mri}/

# Remove the binary extension sources and build leftovers.
rm -rf %{buildroot}/%{gem_instdir}/ext/

# Fix permission
chmod +x %{buildroot}/%{gem_instdir}/test/fixtures/laholator.py

%check
pushd .%{gem_instdir}
# Set locale to UTF due to failing tests in mock
# https://github.com/brianmario/charlock_holmes/issues/39
LANG=C.UTF-8
ruby -I"lib:%{buildroot}%{gem_extdir_mri}" test/*.rb
popd

%files
%dir %{gem_instdir}
%{gem_libdir}
%{gem_extdir_mri}
%{gem_spec}
%doc %{gem_instdir}/MIT-LICENSE
%exclude %{gem_cache}
%exclude %{gem_instdir}/.*

%files doc
%doc %{gem_docdir}
%doc %{gem_instdir}/README.md
%{gem_instdir}/Gemfile
%{gem_instdir}/Rakefile
%{gem_instdir}/benchmark/
%{gem_instdir}/test/
%exclude %{gem_instdir}/%{gem_name}.gemspec


%changelog
* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.3-28
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Jan 24 2019 Mamoru TASAKA <mtasaka@fedoraproject.org> - 0.7.3-27
- F-30: rebuild again against ruby26

* Wed Jan 23 2019 Pete Walter <pwalter@fedoraproject.org> - 0.7.3-26
- Rebuild for ICU 63

* Thu Jan 17 2019 Vít Ondruch <vondruch@redhat.com> - 0.7.3-25
- Rebuilt for https://fedoraproject.org/wiki/Changes/Ruby_2.6

* Sun Nov 18 2018 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 0.7.3-24
- Use C.UTF-8 locale
  See https://fedoraproject.org/wiki/Changes/Remove_glibc-langpacks-all_from_buildroot

* Fri Aug 31 2018 Vít Ondruch <vondruch@redhat.com> - 0.7.3-23
- Fix ICU 61+ compatibility (rhbz#1606169).

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.3-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jul 10 2018 Pete Walter <pwalter@fedoraproject.org> - 0.7.3-21
- Rebuild for ICU 62

* Mon Apr 30 2018 Pete Walter <pwalter@fedoraproject.org> - 0.7.3-20
- Rebuild for ICU 61.1

* Fri Feb 09 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.7.3-19
- Escape macros in %%changelog

* Sat Jan 20 2018 Björn Esser <besser82@fedoraproject.org> - 0.7.3-18
- Rebuilt for switch to libxcrypt

* Fri Jan 05 2018 Mamoru TASAKA <mtasaka@fedoraproject.org> - 0.7.3-17
- F-28: rebuild for ruby25

* Thu Nov 30 2017 Pete Walter <pwalter@fedoraproject.org> - 0.7.3-16
- Rebuild for ICU 60.1

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.3-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.3-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.3-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jan 10 2017 Vít Ondruch <vondruch@redhat.com> - 0.7.3-12
- Rebuilt for https://fedoraproject.org/wiki/Changes/Ruby_2.4

* Fri Apr 15 2016 David Tardon <dtardon@redhat.com> - 0.7.3-11
- rebuild for ICU 57.1

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.3-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 08 2016 Vít Ondruch <vondruch@redhat.com> - 0.7.3-9
- Rebuilt for https://fedoraproject.org/wiki/Changes/Ruby_2.3

* Wed Oct 28 2015 David Tardon <dtardon@redhat.com> - 0.7.3-8
- rebuild for ICU 56.1

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 0.7.3-6
- Rebuilt for GCC 5 C++11 ABI change

* Mon Jan 26 2015 David Tardon <dtardon@redhat.com> - 0.7.3-5
- rebuild for ICU 54.1

* Thu Jan 15 2015 Vít Ondruch <vondruch@redhat.com> - 0.7.3-4
- Rebuilt for https://fedoraproject.org/wiki/Changes/Ruby_2.2

* Tue Aug 26 2014 David Tardon <dtardon@redhat.com> - 0.7.3-3
- rebuild for ICU 53.1

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Jun 11 2014 Ken Dreyer <ktdreyer@ktdreyer.com> - 0.7.3-1
- Update to charlock_holmes 0.7.3 (RHBZ #1105821)
- Use HTTPS URL

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Ken Dreyer <ktdreyer@ktdreyer.com> - 0.7.1-1
- Update to charlock_holmes 0.7.1 (RHBZ #1100754)

* Mon May 12 2014 Ken Dreyer <ktdreyer@ktdreyer.com> - 0.7.0-1
- Update to charlock_holmes 0.7.0 (supports Minitest 5)
- rm gem2rpm auto-generated comment
- exclude extra gemspec

* Wed Apr 09 2014 Achilleas Pipinellis <axilleas@fedoraproject.org> - 0.6.9.4-5
- Rebuilt for https://fedoraproject.org/wiki/Changes/Ruby_2.1
- Use minitest4

* Fri Feb 14 2014 David Tardon <dtardon@redhat.com> - 0.6.9.4-4
- rebuild for new ICU

* Wed Aug 07 2013 Axilleas Pipinellis <axilleaspi@ymail.com> - 0.6.9.4-3
- Filter /usr/bin/env from RPM's autorequires
- Removed extra newline from description

* Sun Aug 04 2013 Axilleas Pipinellis <axilleaspi@ymail.com> - 0.6.9.4-2
- Move bundler removal to %%prep
- Include github issue of failing tests

* Mon Jul 22 2013 Axilleas Pipinellis <axilleaspi@ymail.com> - 0.6.9.4-1
- Initial package
